import 'package:flutter/material.dart';

import 'package:varx_design_system/components/buttons/varx_primary_button.dart';
import 'package:varx_design_system/components/buttons/varx_secondary_button.dart';
import 'package:varx_design_system/components/buttons/varx_tertiary_button.dart';
import 'package:varx_design_system/components/buttons/varx_text_button.dart';

enum VarxButtonType { primary, secondary, tertiary, text }

class VarxButton extends StatelessWidget {
  const VarxButton({
    Key? key,
    this.type = VarxButtonType.primary,
    this.onTap,
    required this.label,
    this.prefixIcon,
    this.prefixIconData,
    this.suffixIcon,
    this.suffixIconData,
    this.loadingIndicator,
    this.isLoading = false,
    this.borderRadius,
    this.loadingColor,
    this.buttonStyle,
    this.primary,
    this.onprimary,
    this.fullWidth = true,
  }) : super(key: key);

  final VarxButtonType type;
  final Function()? onTap;
  final String label;
  final Widget? prefixIcon;
  final IconData? prefixIconData;
  final Widget? suffixIcon;
  final IconData? suffixIconData;
  final Widget? loadingIndicator;
  final bool isLoading;
  final BorderRadius? borderRadius;
  final Color? loadingColor;
  final ButtonStyle? buttonStyle;
  final Color? primary;
  final Color? onprimary;
  final bool fullWidth;

  @override
  Widget build(BuildContext context) {
    if (type == VarxButtonType.secondary) {
      return VarxSecondaryButton(
        label: label,
        onTap: onTap,
        prefixIcon: prefixIcon,
        prefixIconData: prefixIconData,
        suffixIcon: suffixIcon,
        suffixIconData: suffixIconData,
        loadingIndicator: loadingIndicator,
        isLoading: isLoading,
        borderRadius: borderRadius,
        loadingColor: loadingColor,
        buttonStyle: buttonStyle,
        primary: primary,
        onprimary: onprimary,
        fullWidth: fullWidth,
      );
    } else if (type == VarxButtonType.tertiary) {
      return VarxTertiaryButton(
        label: label,
        onTap: onTap,
        prefixIcon: prefixIcon,
        prefixIconData: prefixIconData,
        suffixIcon: suffixIcon,
        suffixIconData: suffixIconData,
        loadingIndicator: loadingIndicator,
        isLoading: isLoading,
        borderRadius: borderRadius,
        loadingColor: loadingColor,
        buttonStyle: buttonStyle,
        primary: primary,
        onprimary: onprimary,
        fullWidth: fullWidth,
      );
    } else if (type == VarxButtonType.text) {
      return VarxTextButton(
        label: label,
        onTap: onTap,
        prefixIcon: prefixIcon,
        prefixIconData: prefixIconData,
        suffixIcon: suffixIcon,
        suffixIconData: suffixIconData,
        loadingIndicator: loadingIndicator,
        isLoading: isLoading,
        borderRadius: borderRadius,
        loadingColor: loadingColor,
        buttonStyle: buttonStyle,
        primary: primary,
        onprimary: onprimary,
        fullWidth: fullWidth,
      );
    }
    return VarxPrimaryButton(
      label: label,
      onTap: onTap,
      prefixIcon: prefixIcon,
      prefixIconData: prefixIconData,
      suffixIcon: suffixIcon,
      suffixIconData: suffixIconData,
      loadingIndicator: loadingIndicator,
      isLoading: isLoading,
      borderRadius: borderRadius,
      loadingColor: loadingColor,
      buttonStyle: buttonStyle,
      primary: primary,
      onprimary: onprimary,
      fullWidth: fullWidth,
    );
  }
}
