import 'package:flutter/material.dart';

import 'package:varx_design_system/components/buttons/content_button.dart';
import 'package:varx_design_system/components/buttons/loading_button_indicator.dart';

class VarxPrimaryButton extends StatelessWidget {
  const VarxPrimaryButton({
    Key? key,
    this.onTap,
    required this.label,
    this.prefixIcon,
    this.prefixIconData,
    this.suffixIcon,
    this.suffixIconData,
    this.loadingIndicator,
    this.isLoading = false,
    this.borderRadius,
    this.loadingColor,
    this.buttonStyle,
    this.primary,
    this.onprimary,
    this.fullWidth = true,
  }) : super(key: key);

  final Function()? onTap;
  final String label;
  final Widget? prefixIcon;
  final IconData? prefixIconData;
  final Widget? suffixIcon;
  final IconData? suffixIconData;
  final Widget? loadingIndicator;
  final bool isLoading;
  final BorderRadius? borderRadius;
  final Color? loadingColor;
  final ButtonStyle? buttonStyle;
  final Color? primary;
  final Color? onprimary;
  final bool fullWidth;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onTap,
      style: buttonStyle ??
          ElevatedButton.styleFrom(
            primary: primary,
            onPrimary: onprimary,
            shape: RoundedRectangleBorder(
              borderRadius: borderRadius ?? BorderRadius.circular(8),
            ),
          ),
      child: isLoading
          ? LoadingButtonIndicator(
              loadingColor: loadingColor,
              fullWidth: fullWidth,
            )
          : ContentButton(
              fullWidth: fullWidth,
              prefixIcon: prefixIconData != null
                  ? Icon(
                      prefixIconData,
                      size: 18,
                    )
                  : prefixIcon,
              label: label,
              suffixIcon: suffixIconData != null
                  ? Icon(
                      suffixIconData,
                      size: 18,
                    )
                  : suffixIcon,
            ),
    );
  }
}
