import 'package:flutter/material.dart';

class VarxExpansionTile extends StatelessWidget {
  const VarxExpansionTile({
    Key? key,
    required this.title,
    required this.children,
    this.initiallyExpanded = true,
    this.backgroundColor,
  }) : super(key: key);

  final String title;
  final List<Widget> children;
  final bool initiallyExpanded;
  final Color? backgroundColor;

  @override
  Widget build(BuildContext context) {
    return Card(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(0),
      ),
      margin: const EdgeInsets.only(bottom: 4),
      color: backgroundColor,
      child: Theme(
        data: Theme.of(context).copyWith(dividerColor: Colors.transparent),
        child: ExpansionTile(
          initiallyExpanded: initiallyExpanded,
          expandedAlignment: Alignment.topLeft,
          expandedCrossAxisAlignment: CrossAxisAlignment.start,
          tilePadding: const EdgeInsets.symmetric(
            horizontal: 20,
          ),
          childrenPadding: const EdgeInsets.fromLTRB(20, 0, 20, 20),
          title: Text(
            title,
            style: Theme.of(context).textTheme.titleMedium?.copyWith(
                  color: Theme.of(context).colorScheme.primary,
                  fontWeight: FontWeight.bold,
                ),
          ),
          children: children,
        ),
      ),
    );
  }
}
