import 'package:flutter/material.dart';

import 'package:varx_design_system/components/texts/text_label.dart';

class VarxTextField extends StatelessWidget {
  const VarxTextField({
    Key? key,
    this.controller,
    this.padding,
    this.onChanged,
    this.label,
    this.innerLabel,
    this.hintText,
    this.obscureText = false,
    this.errorText,
    this.prefixIcon,
    this.suffixIcon,
    this.isRequired = false,
    this.keyboardType,
    this.maxLines = 1,
    this.autovalidateMode,
    this.enabled = true,
    this.validator,
    this.textInputAction,
    this.keyboardAppearance,
    this.fillColor,
    this.inputDecoration,
    this.onTap,
    this.onEditingComplete,
    this.onFieldSubmitted,
  }) : super(key: key);

  final TextEditingController? controller;
  final EdgeInsetsGeometry? padding;
  final void Function(String)? onChanged;
  final String? label;
  final String? innerLabel;
  final String? hintText;
  final bool obscureText;
  final String? errorText;
  final Widget? prefixIcon;
  final Widget? suffixIcon;
  final bool isRequired;
  final TextInputType? keyboardType;
  final int? maxLines;
  final AutovalidateMode? autovalidateMode;
  final bool enabled;
  final String? Function(String?)? validator;
  final TextInputAction? textInputAction;
  final Brightness? keyboardAppearance;
  final Color? fillColor;
  final InputDecoration? inputDecoration;
  final Function()? onTap;
  final Function()? onEditingComplete;
  final Function(String)? onFieldSubmitted;

  @override
  Widget build(BuildContext context) {
    final brightness = MediaQuery.of(context).platformBrightness;

    final isDarkMode = brightness == Brightness.dark;

    return Padding(
      padding: padding ?? const EdgeInsets.only(bottom: 16),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          if (label != null)
            TextLabel(
              label: label,
              isRequired: isRequired,
            ),
          const SizedBox(height: 8),
          TextFormField(
            controller: controller,
            onChanged: onChanged,
            onTap: onTap,
            onEditingComplete: onEditingComplete,
            onFieldSubmitted: onFieldSubmitted,
            obscureText: obscureText,
            keyboardType: keyboardType,
            maxLines: maxLines,
            autovalidateMode: autovalidateMode,
            enabled: enabled,
            validator: validator,
            textInputAction: textInputAction,
            keyboardAppearance: keyboardAppearance,
            decoration: inputDecoration ??
                InputDecoration(
                  fillColor: fillColor ??
                      (enabled
                          ? isDarkMode
                              ? Theme.of(context).colorScheme.surface
                              : Colors.white
                          : Theme.of(context).colorScheme.surfaceVariant),
                  prefixIcon: prefixIcon,
                  suffixIcon: suffixIcon,
                  hintText: hintText,
                  errorText: errorText,
                  labelText: innerLabel,
                ),
          ),
        ],
      ),
    );
  }
}
