import 'package:flutter/material.dart';
import 'package:varx_design_system/themes/varx_color.dart';

class BulletList extends StatelessWidget {
  const BulletList({
    Key? key,
    required this.title,
    this.subtitle,
  }) : super(key: key);

  final String title;
  final String? subtitle;

  @override
  Widget build(BuildContext context) {
    final brightness = MediaQuery.of(context).platformBrightness;

    final isDarkMode = brightness == Brightness.dark;

    return Padding(
      padding: const EdgeInsets.only(bottom: 8),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            '•',
            style: Theme.of(context).textTheme.labelLarge,
          ),
          const SizedBox(width: 8),
          Expanded(
            child: RichText(
              text: TextSpan(
                text: title,
                style: Theme.of(context).textTheme.bodyLarge,
                children: [
                  if (subtitle != null)
                    TextSpan(
                      text: '\n$subtitle',
                      style: Theme.of(context).textTheme.bodyLarge?.copyWith(
                            color: isDarkMode
                                ? VarxColor.neutral80
                                : VarxColor.neutral60,
                          ),
                    )
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
