import 'package:flutter/material.dart';
import 'package:varx_design_system/themes/varx_color.dart';

class LabelValue extends StatelessWidget {
  const LabelValue({
    Key? key,
    this.padding,
    this.crossAxisAlignment = CrossAxisAlignment.start,
    required this.label,
    this.labelColor,
    this.labelStyle,
    this.value,
    this.child,
    this.labelWeight,
    this.valueStyle,
  }) : super(key: key);

  final EdgeInsetsGeometry? padding;
  final CrossAxisAlignment crossAxisAlignment;
  final String label;
  final Color? labelColor;
  final TextStyle? labelStyle;
  final String? value;
  final Widget? child;
  final FontWeight? labelWeight;
  final TextStyle? valueStyle;

  @override
  Widget build(BuildContext context) {
    final brightness = MediaQuery.of(context).platformBrightness;

    final isDarkMode = brightness == Brightness.dark;

    return Padding(
      padding: padding ?? const EdgeInsets.only(bottom: 16),
      child: Column(
        crossAxisAlignment: crossAxisAlignment,
        children: [
          Text(
            label,
            style: labelStyle ??
                Theme.of(context).textTheme.labelLarge?.copyWith(
                      color: labelColor ??
                          (isDarkMode
                              ? VarxColor.neutral80
                              : VarxColor.neutral60),
                    ),
          ),
          const SizedBox(height: 4),
          if (child != null)
            child!
          else if (value != null)
            Text(
              value!,
              style: valueStyle ??
                  Theme.of(context).textTheme.bodyLarge?.copyWith(
                        fontWeight: labelWeight,
                      ),
            ),
        ],
      ),
    );
  }
}
